# frozen_string_literal: true

Rails.application.routes.draw do
  devise_for :usuaries
  get '/.well-known/change-password', to: redirect('/usuaries/edit')

  root 'application#index'

  constraints(Constraints::ApiSubdomain.new) do
    scope module: 'api' do
      namespace :v1 do
        resources :csp_reports, only: %i[create]

        resources :sites, only: %i[index], constraints: { site_id: /[a-z0-9\-.]+/, id: /[a-z0-9\-.]+/ } do
          get  :'invitades/cookie', to: 'invitades#cookie'
          post :'posts/:layout', to: 'posts#create', as: :posts

          get  :'contact/cookie', to: 'invitades#contact_cookie'
          post :'contact/:form', to: 'contact#receive', as: :contact

          post :'webhooks/pull', to: 'webhooks#pull'
        end
      end
    end
  end

  # Las rutas privadas empiezan con una ruta única para poder hacer un
  # alias en nginx sin tener que usar expresiones regulares para
  # detectar el nombre del sitio.
  get '/sites/private/:site_id(*file)', to: 'private#show', constraints: { site_id: %r{[^/]+} }
  get '/env.js', to: 'env#index'

  match '/api/v3/projects/:site_id/notices' => 'api/v1/notices#create', via: %i[post]

  resources :sites, constraints: { site_id: %r{[^/]+}, id: %r{[^/]+} } do
    # Gestionar actualizaciones del sitio
    get 'pull', to: 'sites#fetch'
    post 'pull', to: 'sites#merge'

    # Gestionar usuaries
    get 'usuaries/invite', to: 'usuaries#invite'
    post 'usuaries/invite', to: 'usuaries#send_invitations'
    patch 'usuaries/accept_invitation', to: 'usuaries#accept_invitation'
    patch 'usuaries/reject_invitation', to: 'usuaries#reject_invitation'
    resources :usuaries do
      patch 'demote', to: 'usuaries#demote'
      patch 'promote', to: 'usuaries#promote'
    end

    get 'collaborate', to: 'collaborations#collaborate'
    post 'collaborate', to: 'collaborations#accept_collaboration'

    get 'moderation_queue', to: 'moderation_queue#index'
    get 'remote_profile', to: 'moderation_queue#remote_profile'
    get 'instances', to: 'moderation_queue#instances'

    # Gestionar artículos según idioma
    nested do
      scope '/(:locale)', constraint: /[a-z]{2}(-[A-Z]{2})?/ do
        post :'posts/reorder', to: 'posts#reorder'
        resources :posts do
          get 'p/:page', action: :index, on: :collection
          get :preview, to: 'posts#preview'
        end
      end
    end

    # Gestionar traducciones
    get 'i18n', to: 'i18n#index'
    get 'i18n/edit', to: 'i18n#edit'
    post 'i18n', to: 'i18n#update'

    # Compilar el sitio
    post 'enqueue', to: 'sites#enqueue'
    post 'reorder_posts', to: 'sites#reorder_posts'

    resources :stats, only: [:index]
    get :'stats/host', to: 'stats#host'
    get :'stats/uris', to: 'stats#uris'
    get :'stats/resources', to: 'stats#resources'

    resources :build_stats, only: %i[index]
  end
end
